@@ -1,7 +1,6 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-"""Utility routines for working with points and affine transforms
-"""
+"""Utility routines for working with points and affine transforms"""
 from functools import reduce
 
 import numpy as np
@@ -100,7 +99,7 @@ def apply_affine(aff, pts, inplace=False):
 
 
 def to_matvec(transform):
-    """Split a transform into its matrix and vector components.
+    """Split a transform into its matrix and vector components
 
     The transformation must be represented in homogeneous coordinates and is
     split into its rotation matrix and translation vector components.
@@ -312,8 +311,7 @@ def voxel_sizes(affine):
 
 
 def obliquity(affine):
-    r"""
-    Estimate the *obliquity* an affine's axes represent.
+    r"""Estimate the *obliquity* an affine's axes represent
 
     The term *obliquity* is defined here as the rotation of those axes with
     respect to the cardinal axes.
