@@ -6,8 +6,7 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-"""
-Class for reading AFNI BRIK/HEAD datasets
+"""Class for reading AFNI BRIK/HEAD datasets
 
 See https://afni.nimh.nih.gov/pub/dist/doc/program_help/README.attributes.html
 for information on what is required to have a valid BRIK/HEAD dataset.
@@ -476,6 +475,7 @@ class AFNIImage(SpatialImage):
     """
 
     header_class = AFNIHeader
+    header: AFNIHeader
     valid_exts = ('.brik', '.head')
     files_types = (('image', '.brik'), ('header', '.head'))
     _compressed_suffixes = ('.gz', '.bz2', '.Z', '.zst')
@@ -564,4 +564,4 @@ class AFNIImage(SpatialImage):
         return file_map
 
 
-load = AFNIImage.load
+load = AFNIImage.from_filename
