@@ -203,13 +203,13 @@ class Cifti2Parser(xml.XmlParser):
                 applies_to_matrix_dimension=dimensions,
                 indices_map_to_data_type=attrs['IndicesMapToDataType'],
             )
-            for key, dtype in [
+            for key, dtype in (
                 ('NumberOfSeriesPoints', int),
                 ('SeriesExponent', int),
                 ('SeriesStart', float),
                 ('SeriesStep', float),
                 ('SeriesUnit', str),
-            ]:
+            ):
                 if key in attrs:
                     setattr(mim, _underscore(key), dtype(attrs[key]))
             matrix = self.struct_state[-1]
@@ -366,13 +366,13 @@ class Cifti2Parser(xml.XmlParser):
                     'BrainModel element can only be a child of a MatrixIndicesMap '
                     'with CIFTI_INDEX_TYPE_BRAIN_MODELS type'
                 )
-            for key, dtype in [
+            for key, dtype in (
                 ('IndexOffset', int),
                 ('IndexCount', int),
                 ('ModelType', str),
                 ('BrainStructure', str),
                 ('SurfaceNumberOfVertices', int),
-            ]:
+            ):
                 if key in attrs:
                     setattr(model, _underscore(key), dtype(attrs[key]))
             if model.brain_structure not in CIFTI_BRAIN_STRUCTURES:
