@@ -16,56 +16,72 @@ Notes:
       with native endianness used in data files.
 """
 
+import hashlib
+import os
 import re
 import sys
 from collections import OrderedDict
-from optparse import OptionParser, Option
+from optparse import Option, OptionParser
 
 import numpy as np
 
 import nibabel as nib
 import nibabel.cmdline.utils
-import hashlib
-import os
 
 
 def get_opt_parser():
     # use module docstring for help output
     p = OptionParser(
-        usage=f"{sys.argv[0]} [OPTIONS] [FILE ...]\n\n" + __doc__,
-        version="%prog " + nib.__version__)
+        usage=f'{sys.argv[0]} [OPTIONS] [FILE ...]\n\n' + __doc__,
+        version='%prog ' + nib.__version__,
+    )
 
-    p.add_options([
-        Option("-v", "--verbose", action="count",
-               dest="verbose", default=0,
-               help="Make more noise.  Could be specified multiple times"),
-
-        Option("-H", "--header-fields",
-               dest="header_fields", default='all',
-               help="Header fields (comma separated) to be printed as well"
-                    " (if present)"),
-
-        Option("--ma", "--data-max-abs-diff",
-               dest="data_max_abs_diff",
-               type=float,
-               default=0.0,
-               help="Maximal absolute difference in data between files"
-                    " to tolerate."),
-
-        Option("--mr", "--data-max-rel-diff",
-               dest="data_max_rel_diff",
-               type=float,
-               default=0.0,
-               help="Maximal relative difference in data between files to"
-                    " tolerate. If --data-max-abs-diff is also specified,"
-                    " only the data points with absolute difference greater"
-                    " than that value would be considered for relative"
-                    " difference check."),
-        Option("--dt", "--datatype",
-               dest="dtype",
-               default=np.float64,
-               help="Enter a numpy datatype such as 'float32'.")
-    ])
+    p.add_options(
+        [
+            Option(
+                '-v',
+                '--verbose',
+                action='count',
+                dest='verbose',
+                default=0,
+                help='Make more noise.  Could be specified multiple times',
+            ),
+            Option(
+                '-H',
+                '--header-fields',
+                dest='header_fields',
+                default='all',
+                help='Header fields (comma separated) to be printed as well (if present)',
+            ),
+            Option(
+                '--ma',
+                '--data-max-abs-diff',
+                dest='data_max_abs_diff',
+                type=float,
+                default=0.0,
+                help='Maximal absolute difference in data between files to tolerate.',
+            ),
+            Option(
+                '--mr',
+                '--data-max-rel-diff',
+                dest='data_max_rel_diff',
+                type=float,
+                default=0.0,
+                help='Maximal relative difference in data between files to'
+                ' tolerate. If --data-max-abs-diff is also specified,'
+                ' only the data points with absolute difference greater'
+                ' than that value would be considered for relative'
+                ' difference check.',
+            ),
+            Option(
+                '--dt',
+                '--datatype',
+                dest='dtype',
+                default=np.float64,
+                help="Enter a numpy datatype such as 'float32'.",
+            ),
+        ]
+    )
 
     return p
 
@@ -73,7 +89,7 @@ def get_opt_parser():
 def are_values_different(*values):
     """Generically compare values, return True if different
 
-    Note that comparison is targetting reporting of comparison of the headers
+    Note that comparison is targeting reporting of comparison of the headers
     so has following specifics:
     - even a difference in data types is considered a difference, i.e. 1 != 1.0
     - nans are considered to be the "same", although generally nan != nan
@@ -94,7 +110,7 @@ def are_values_different(*values):
         except TypeError as exc:
             str_exc = str(exc)
             # Not implemented in numpy 1.7.1
-            if "not supported" in str_exc or "ot implemented" in str_exc:
+            if 'not supported' in str_exc or 'not implemented' in str_exc:
                 value0_nans = None
             else:
                 raise
@@ -104,8 +120,7 @@ def are_values_different(*values):
             return True
         elif isinstance(value0, np.ndarray):
             # use .dtype.type to provide endianness agnostic comparison
-            if value0.dtype.type != value.dtype.type or \
-               value0.shape != value.shape:
+            if value0.dtype.type != value.dtype.type or value0.shape != value.shape:
                 return True
             # there might be nans and they need special treatment
             if value0_nans is not None:
@@ -159,15 +174,15 @@ def get_headers_diff(file_headers, names=None):
 def get_data_hash_diff(files, dtype=np.float64):
     """Get difference between md5 values of data
 
-        Parameters
-        ----------
-        files: list of actual files
+    Parameters
+    ----------
+    files: list of actual files
 
-        Returns
-        -------
-        list
-          np.array: md5 values of respective files
-        """
+    Returns
+    -------
+    list
+      np.array: md5 values of respective files
+    """
 
     md5sums = [
         hashlib.md5(np.ascontiguousarray(nib.load(f).get_fdata(dtype=dtype))).hexdigest()
@@ -209,14 +224,13 @@ def get_data_diff(files, max_abs=0, max_rel=0, dtype=np.float64):
     """
 
     # we are doomed to keep them in RAM now
-    data = [f if isinstance(f, np.ndarray) else nib.load(f).get_fdata(dtype=dtype)
-            for f in files]
+    data = [f if isinstance(f, np.ndarray) else nib.load(f).get_fdata(dtype=dtype) for f in files]
     diffs = OrderedDict()
     for i, d1 in enumerate(data[:-1]):
         # populate empty entries for non-compared
         diffs1 = [None] * (i + 1)
 
-        for j, d2 in enumerate(data[i + 1:], i + 1):
+        for j, d2 in enumerate(data[i + 1 :], i + 1):
 
             if d1.shape == d2.shape:
                 abs_diff = np.abs(d1 - d2)
@@ -234,7 +248,7 @@ def get_data_diff(files, max_abs=0, max_rel=0, dtype=np.float64):
                         # Since we operated on sub-selected values already, we need
                         # to plug them back in
                         candidates[
-                            tuple((indexes[sub_thr] for indexes in np.where(candidates)))
+                            tuple(indexes[sub_thr] for indexes in np.where(candidates))
                         ] = False
                     max_rel_diff = np.max(rel_diff)
                 else:
@@ -251,7 +265,7 @@ def get_data_diff(files, max_abs=0, max_rel=0, dtype=np.float64):
                     diffs1.append(None)
 
             else:
-                diffs1.append({'CMP': "incompat"})
+                diffs1.append({'CMP': 'incompat'})
 
         if any(diffs1):
 
@@ -263,28 +277,28 @@ def get_data_diff(files, max_abs=0, max_rel=0, dtype=np.float64):
 def display_diff(files, diff):
     """Format header differences into a nice string
 
-        Parameters
-        ----------
-        files: list of files that were compared so we can print their names
-        diff: dict of different valued header fields
+    Parameters
+    ----------
+    files: list of files that were compared so we can print their names
+    diff: dict of different valued header fields
 
-        Returns
-        -------
-        str
-          string-formatted table of differences
+    Returns
+    -------
+    str
+      string-formatted table of differences
     """
-    output = ""
-    field_width = "{:<15}"
-    filename_width = "{:<53}"
-    value_width = "{:<55}"
+    output = ''
+    field_width = '{:<15}'
+    filename_width = '{:<53}'
+    value_width = '{:<55}'
 
-    output += "These files are different.\n"
+    output += 'These files are different.\n'
     output += field_width.format('Field/File')
 
     for i, f in enumerate(files, 1):
-        output += "%d:%s" % (i, filename_width.format(os.path.basename(f)))
+        output += '%d:%s' % (i, filename_width.format(os.path.basename(f)))
 
-    output += "\n"
+    output += '\n'
 
     for key, value in diff.items():
         output += field_width.format(key)
@@ -305,14 +319,15 @@ def display_diff(files, diff):
             item_str = re.sub('[\x00]', '?', item_str)
             output += value_width.format(item_str)
 
-        output += "\n"
+        output += '\n'
 
     return output
 
 
-def diff(files, header_fields='all', data_max_abs_diff=None,
-         data_max_rel_diff=None, dtype=np.float64):
-    assert len(files) >= 2, "Please enter at least two files"
+def diff(
+    files, header_fields='all', data_max_abs_diff=None, data_max_rel_diff=None, dtype=np.float64
+):
+    assert len(files) >= 2, 'Please enter at least two files'
 
     file_headers = [nib.load(f).header for f in files]
 
@@ -330,10 +345,9 @@ def diff(files, header_fields='all', data_max_abs_diff=None,
     if data_md5_diffs:
         # provide details, possibly triggering the ignore of the difference
         # in data
-        data_diffs = get_data_diff(files,
-                                   max_abs=data_max_abs_diff,
-                                   max_rel=data_max_rel_diff,
-                                   dtype=dtype)
+        data_diffs = get_data_diff(
+            files, max_abs=data_max_abs_diff, max_rel=data_max_rel_diff, dtype=dtype
+        )
         if data_diffs:
             diff['DATA(md5)'] = data_md5_diffs
             diff.update(data_diffs)
@@ -359,12 +373,12 @@ def main(args=None, out=None):
         header_fields=opts.header_fields,
         data_max_abs_diff=opts.data_max_abs_diff,
         data_max_rel_diff=opts.data_max_rel_diff,
-        dtype=opts.dtype
+        dtype=opts.dtype,
     )
 
     if files_diff:
         out.write(display_diff(files, files_diff))
         raise SystemExit(1)
     else:
-        out.write("These files are identical.\n")
+        out.write('These files are identical.\n')
         raise SystemExit(0)
