@@ -2,19 +2,21 @@
 Convert tractograms (TRK -> TCK).
 """
 
-import os
 import argparse
+import os
 
 import nibabel as nib
 
 
 def parse_args():
-    DESCRIPTION = "Convert tractograms (TRK -> TCK)."
+    DESCRIPTION = 'Convert tractograms (TRK -> TCK).'
     parser = argparse.ArgumentParser(description=DESCRIPTION)
-    parser.add_argument("tractograms", metavar="tractogram", nargs="+",
-                        help="list of tractograms (.trk).")
-    parser.add_argument("-f", "--force", action="store_true",
-                        help="overwrite existing output files.")
+    parser.add_argument(
+        'tractograms', metavar='tractogram', nargs='+', help='list of tractograms (.trk).'
+    )
+    parser.add_argument(
+        '-f', '--force', action='store_true', help='overwrite existing output files.'
+    )
 
     args = parser.parse_args()
     return args, parser
