@@ -1,8 +1,6 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-"""
-Utilities to find files from NIPY data packages
-"""
+"""Utilities to find files from NIPY data packages"""
 import configparser
 import glob
 import os
