@@ -1,6 +1,4 @@
-"""Utilities for getting array slices out of file-like objects
-"""
-
+"""Utilities for getting array slices out of file-like objects"""
 import operator
 from functools import reduce
 from mmap import mmap
