@@ -228,7 +228,7 @@ class GiftiLabelTable(xml.XmlSerializable):
             label = xml.SubElement(labeltable, 'Label')
             label.attrib['Key'] = str(ele.key)
             label.text = ele.label
-            for attr in ['Red', 'Green', 'Blue', 'Alpha']:
+            for attr in ('Red', 'Green', 'Blue', 'Alpha'):
                 if getattr(ele, attr.lower(), None) is not None:
                     label.attrib[attr] = str(getattr(ele, attr.lower()))
         return labeltable
@@ -745,7 +745,7 @@ class GiftiImage(xml.XmlSerializable, SerializableImage):
         >>> triangles_2 = surf_img.agg_data('triangle')
         >>> triangles_3 = surf_img.agg_data(1009)  # Numeric code for pointset
         >>> print(np.array2string(triangles))
-        [0 1 2]
+        [[0 1 2]]
         >>> np.array_equal(triangles, triangles_2)
         True
         >>> np.array_equal(triangles, triangles_3)
@@ -852,7 +852,7 @@ class GiftiImage(xml.XmlSerializable, SerializableImage):
             GIFTI.append(dar._to_xml_element())
         return GIFTI
 
-    def to_xml(self, enc='utf-8', *, mode='strict') -> bytes:
+    def to_xml(self, enc='utf-8', *, mode='strict', **kwargs) -> bytes:
         """Return XML corresponding to image content"""
         if mode == 'strict':
             if any(arr.datatype not in GIFTI_DTYPES for arr in self.darrays):
@@ -882,7 +882,7 @@ class GiftiImage(xml.XmlSerializable, SerializableImage):
         header = b"""<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE GIFTI SYSTEM "http://www.nitrc.org/frs/download.php/115/gifti.dtd">
 """
-        return header + super().to_xml(enc)
+        return header + super().to_xml(enc, **kwargs)
 
     # Avoid the indirection of going through to_file_map
     def to_bytes(self, enc='utf-8', *, mode='strict'):
