@@ -25,6 +25,8 @@ and compare against command line output of::
 
     mincstats my_funny.mnc
 """
+import warnings
+
 import numpy as np
 
 from .minc1 import Minc1File, Minc1Image, MincError, MincHeader
@@ -58,8 +60,13 @@ class Minc2File(Minc1File):
         # We don't currently support irregular spacing
         # https://en.wikibooks.org/wiki/MINC/Reference/MINC2.0_File_Format_Reference#Dimension_variable_attributes
         for dim in self._dims:
-            if dim.spacing != b'regular__':
+            # "If this attribute is absent, a value of regular__ should be assumed."
+            spacing = getattr(dim, 'spacing', b'regular__')
+            if spacing == b'irregular':
                 raise ValueError('Irregular spacing not supported')
+            elif spacing != b'regular__':
+                warnings.warn(f'Invalid spacing declaration: {spacing}; assuming regular')
+
         self._spatial_dims = [name for name in self._dim_names if name.endswith('space')]
         self._image_max = image['image-max']
         self._image_min = image['image-min']
