@@ -44,9 +44,9 @@ def wrapper_from_file(file_like, *args, **kwargs):
        filename string or file-like object, pointing to a valid DICOM
        file readable by ``pydicom``
     \*args : positional
-        args to ``dicom.read_file`` command.
+        args to ``dicom.dcmread`` command.
     \*\*kwargs : keyword
-        args to ``dicom.read_file`` command.  ``force=True`` might be a
+        args to ``dicom.dcmread`` command.  ``force=True`` might be a
         likely keyword argument.
 
     Returns
@@ -55,7 +55,7 @@ def wrapper_from_file(file_like, *args, **kwargs):
        DICOM wrapper corresponding to DICOM data type
     """
     with ImageOpener(file_like) as fobj:
-        dcm_data = pydicom.read_file(fobj, *args, **kwargs)
+        dcm_data = pydicom.dcmread(fobj, *args, **kwargs)
     return wrapper_from_data(dcm_data)
 
 
@@ -509,11 +509,14 @@ class MultiframeWrapper(Wrapper):
         if hasattr(first_frame, 'get') and first_frame.get([0x18, 0x9117]):
             # DWI image may include derived isotropic, ADC or trace volume
             try:
-                self.frames = pydicom.Sequence(
+                anisotropic = pydicom.Sequence(
                     frame
                     for frame in self.frames
                     if frame.MRDiffusionSequence[0].DiffusionDirectionality != 'ISOTROPIC'
                 )
+                # Image contains DWI volumes followed by derived images; remove derived images
+                if len(anisotropic) != 0:
+                    self.frames = anisotropic
             except IndexError:
                 # Sequence tag is found but missing items!
                 raise WrapperError('Diffusion file missing information')
