@@ -1,15 +1,15 @@
-""" Testing Siemens CSA header reader
+"""Testing Siemens CSA header reader
 """
-import sys
 import struct
+import sys
 
 from ..structreader import Unpacker
 
 
 def test_unpacker():
     s = b'1234\x00\x01'
-    le_int, = struct.unpack('<h', b'\x00\x01')
-    be_int, = struct.unpack('>h', b'\x00\x01')
+    (le_int,) = struct.unpack('<h', b'\x00\x01')
+    (be_int,) = struct.unpack('>h', b'\x00\x01')
     if sys.byteorder == 'little':
         native_int = le_int
         swapped_int = be_int
