@@ -17,7 +17,6 @@ from io import BytesIO
 
 import numpy as np
 import numpy.linalg as npl
-from numpy.compat.py3k import asstr
 
 from . import analyze  # module import
 from .arrayproxy import get_obj_dtype
@@ -90,7 +89,7 @@ header_dtype = np.dtype(header_dtd)
 if have_binary128():
     # Only enable 128 bit floats if we really have IEEE binary 128 longdoubles
     _float128t: type[np.generic] = np.longdouble
-    _complex256t: type[np.generic] = np.longcomplex
+    _complex256t: type[np.generic] = np.clongdouble
 else:
     _float128t = np.void
     _complex256t = np.void
@@ -1405,7 +1404,7 @@ class Nifti1Header(SpmAnalyzeHeader):
             raise TypeError('repr can be "label" or "code"')
         n_params = len(recoder.parameters[code]) if known_intent else 0
         params = (float(hdr['intent_p%d' % (i + 1)]) for i in range(n_params))
-        name = asstr(hdr['intent_name'].item())
+        name = hdr['intent_name'].item().decode('latin-1')
         return label, tuple(params), name
 
     def set_intent(self, code, params=(), name='', allow_unknown=False):
@@ -1637,10 +1636,9 @@ class Nifti1Header(SpmAnalyzeHeader):
         labels = so_recoder.value_set('label')
         labels.remove('unknown')
 
-        matching_labels = []
-        for label in labels:
-            if np.all(st_order == self._slice_time_order(label, n_timed)):
-                matching_labels.append(label)
+        matching_labels = [
+            label for label in labels if np.all(st_order == self._slice_time_order(label, n_timed))
+        ]
 
         if not matching_labels:
             raise HeaderDataError(f'slice ordering of {st_order} fits with no known scheme')
@@ -1741,7 +1739,7 @@ class Nifti1Header(SpmAnalyzeHeader):
         magic = hdr['magic'].item()
         if magic in (hdr.pair_magic, hdr.single_magic):
             return hdr, rep
-        rep.problem_msg = f'magic string "{asstr(magic)}" is not valid'
+        rep.problem_msg = f'magic string {magic.decode("latin1")!r} is not valid'
         rep.problem_level = 45
         if fix:
             rep.fix_msg = 'leaving as is, but future errors are likely'
@@ -2444,10 +2442,14 @@ def _get_analyze_compat_dtype(arr):
         return np.dtype('int16' if arr.max() <= np.iinfo(np.int16).max else 'int32')
 
     mn, mx = arr.min(), arr.max()
-    if np.can_cast(mn, np.int32) and np.can_cast(mx, np.int32):
-        return np.dtype('int32')
-    if np.can_cast(mn, np.float32) and np.can_cast(mx, np.float32):
-        return np.dtype('float32')
+    if arr.dtype.kind in 'iu':
+        info = np.iinfo('int32')
+        if mn >= info.min and mx <= info.max:
+            return np.dtype('int32')
+    elif arr.dtype.kind == 'f':
+        info = np.finfo('float32')
+        if mn >= info.min and mx <= info.max:
+            return np.dtype('float32')
 
     raise ValueError(
         f'Cannot find analyze-compatible dtype for array with dtype={dtype} (min={mn}, max={mx})'
