@@ -1,20 +1,31 @@
 """Routines to support optional packages"""
+from __future__ import annotations
+
+import typing as ty
+from types import ModuleType
+
 from packaging.version import Version
 
 from .tripwire import TripWire
 
 
-def _check_pkg_version(pkg, min_version):
-    # Default version checking function
-    if isinstance(min_version, str):
-        min_version = Version(min_version)
-    try:
-        return min_version <= Version(pkg.__version__)
-    except AttributeError:
+def _check_pkg_version(min_version: str | Version) -> ty.Callable[[ModuleType], bool]:
+    min_ver = Version(min_version) if isinstance(min_version, str) else min_version
+
+    def check(pkg: ModuleType) -> bool:
+        pkg_ver = getattr(pkg, '__version__', None)
+        if isinstance(pkg_ver, str):
+            return min_ver <= Version(pkg_ver)
         return False
 
+    return check
 
-def optional_package(name, trip_msg=None, min_version=None):
+
+def optional_package(
+    name: str,
+    trip_msg: str | None = None,
+    min_version: str | Version | ty.Callable[[ModuleType], bool] | None = None,
+) -> tuple[ModuleType | TripWire, bool, ty.Callable[[], None]]:
     """Return package-like thing and module setup for package `name`
 
     Parameters
@@ -81,7 +92,7 @@ def optional_package(name, trip_msg=None, min_version=None):
     elif min_version is None:
         check_version = lambda pkg: True
     else:
-        check_version = lambda pkg: _check_pkg_version(pkg, min_version)
+        check_version = _check_pkg_version(min_version)
     # fromlist=[''] results in submodule being returned, rather than the top
     # level module.  See help(__import__)
     fromlist = [''] if '.' in name else []
@@ -107,11 +118,11 @@ def optional_package(name, trip_msg=None, min_version=None):
         trip_msg = (
             f'We need package {name} for these functions, but ``import {name}`` raised {exc}'
         )
-    pkg = TripWire(trip_msg)
+    trip = TripWire(trip_msg)
 
-    def setup_module():
+    def setup_module() -> None:
         import unittest
 
         raise unittest.SkipTest(f'No {name} for these tests')
 
-    return pkg, False, setup_module
+    return trip, False, setup_module
