@@ -139,6 +139,7 @@ from typing import Literal
 import numpy as np
 
 from .arrayproxy import ArrayLike
+from .casting import sctypes_aliases
 from .dataobj_images import DataobjImage
 from .filebasedimages import FileBasedHeader, FileBasedImage
 from .fileholders import FileMap
@@ -333,7 +334,7 @@ def _supported_np_types(klass: type[HasDtype]) -> set[type[np.generic]]:
         else:
             raise e
     supported = set()
-    for np_type in set(np.sctypeDict.values()):
+    for np_type in sctypes_aliases:
         try:
             obj.set_data_dtype(np_type)
         except HeaderDataError:
@@ -481,7 +482,7 @@ class SpatialImage(DataobjImage):
     def __init__(
         self,
         dataobj: ArrayLike,
-        affine: np.ndarray,
+        affine: np.ndarray | None,
         header: FileBasedHeader | ty.Mapping | None = None,
         extra: ty.Mapping | None = None,
         file_map: FileMap | None = None,
@@ -566,6 +567,7 @@ class SpatialImage(DataobjImage):
 
     def _affine2header(self) -> None:
         """Unconditionally set affine into the header"""
+        assert self._affine is not None
         RZS = self._affine[:3, :3]
         vox = np.sqrt(np.sum(RZS * RZS, axis=0))
         hdr = self._header
