@@ -9,6 +9,7 @@
 
 import os
 import warnings
+from pathlib import Path
 from unittest import TestCase
 
 import numpy as np
@@ -183,8 +184,8 @@ class TestEcatImage(TestCase):
     img = image_class.load(example_file)
 
     def test_file(self):
-        assert self.img.file_map['header'].filename == self.example_file
-        assert self.img.file_map['image'].filename == self.example_file
+        assert Path(self.img.file_map['header'].filename) == Path(self.example_file)
+        assert Path(self.img.file_map['image'].filename) == Path(self.example_file)
 
     def test_save(self):
         tmp_file = 'tinypet_tmp.v'
