@@ -1,13 +1,13 @@
-""" Testing filebasedimages module
+"""Testing filebasedimages module
 """
 
-from itertools import product
 import warnings
+from itertools import product
 
 import numpy as np
+import pytest
 
 from ..filebasedimages import FileBasedHeader, FileBasedImage, SerializableImage
-
 from .test_image_api import GenericImageAPI, SerializeMixin
 
 
@@ -17,7 +17,7 @@ class FBNumpyImage(FileBasedImage):
     files_types = (('image', '.npy'),)
 
     def __init__(self, arr, header=None, extra=None, file_map=None):
-        super(FBNumpyImage, self).__init__(header, extra, file_map)
+        super().__init__(header, extra, file_map)
         self.arr = arr
 
     @property
@@ -58,8 +58,8 @@ class SerializableNumpyImage(FBNumpyImage, SerializableImage):
 
 
 class TestFBImageAPI(GenericImageAPI):
-    """ Validation for FileBasedImage instances
-    """
+    """Validation for FileBasedImage instances"""
+
     # A callable returning an image from ``image_maker(data, header)``
     image_maker = FBNumpyImage
     # A callable returning a header from ``header_maker()``
@@ -79,11 +79,7 @@ class TestFBImageAPI(GenericImageAPI):
             arr = np.arange(np.prod(shape), dtype=dtype).reshape(shape)
             hdr = self.header_maker()
             func = self.make_imaker(arr.copy(), hdr)
-            params = dict(
-                dtype=dtype,
-                data=arr,
-                shape=shape,
-                is_proxy=False)
+            params = dict(dtype=dtype, data=arr, shape=shape, is_proxy=False)
             yield func, params
 
 
@@ -92,8 +88,8 @@ class TestSerializableImageAPI(TestFBImageAPI, SerializeMixin):
 
     @staticmethod
     def _header_eq(header_a, header_b):
-        """ FileBasedHeader is an abstract class, so __eq__ is undefined.
-        Checking for the same header type is sufficient, here. """
+        """FileBasedHeader is an abstract class, so __eq__ is undefined.
+        Checking for the same header type is sufficient, here."""
         return type(header_a) == type(header_b) == FileBasedHeader
 
 
@@ -101,7 +97,6 @@ def test_filebased_header():
     # Test stuff about the default FileBasedHeader
 
     class H(FileBasedHeader):
-
         def __init__(self, seq=None):
             if seq is None:
                 seq = []
@@ -127,3 +122,24 @@ def test_filebased_header():
     hdr4 = H.from_header(None)
     assert isinstance(hdr4, H)
     assert hdr4.a_list == []
+
+
+class MultipartNumpyImage(FBNumpyImage):
+    # We won't actually try to write these out, just need to test an edge case
+    files_types = (('header', '.hdr'), ('image', '.npy'))
+
+
+class SerializableMPNumpyImage(MultipartNumpyImage, SerializableImage):
+    pass
+
+
+def test_multifile_stream_failure():
+    shape = (2, 3, 4)
+    arr = np.arange(np.prod(shape), dtype=np.float32).reshape(shape)
+    img = SerializableMPNumpyImage(arr)
+    with pytest.raises(NotImplementedError):
+        img.to_bytes()
+    img = SerializableNumpyImage(arr)
+    bstr = img.to_bytes()
+    with pytest.raises(NotImplementedError):
+        SerializableMPNumpyImage.from_bytes(bstr)
