@@ -7,10 +7,17 @@
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 """Tests for filename container"""
+import pathlib
 
 import pytest
 
-from ..filename_parser import TypesFilenamesError, parse_filename, splitext_addext, types_filenames
+from ..filename_parser import (
+    TypesFilenamesError,
+    _stringify_path,
+    parse_filename,
+    splitext_addext,
+    types_filenames,
+)
 
 
 def test_filenames():
@@ -123,3 +130,19 @@ def test_splitext_addext():
     assert res == ('..', '', '')
     res = splitext_addext('...')
     assert res == ('...', '', '')
+
+
+def test__stringify_path():
+    res = _stringify_path('fname.ext.gz')
+    assert res == 'fname.ext.gz'
+    res = _stringify_path(pathlib.Path('fname.ext.gz'))
+    assert res == 'fname.ext.gz'
+
+    home = pathlib.Path.home().as_posix()
+    res = _stringify_path(pathlib.Path('~/fname.ext.gz'))
+    assert res == f'{home}/fname.ext.gz'
+
+    res = _stringify_path(pathlib.Path('./fname.ext.gz'))
+    assert res == 'fname.ext.gz'
+    res = _stringify_path(pathlib.Path('../fname.ext.gz'))
+    assert res == '../fname.ext.gz'
