@@ -1,23 +1,24 @@
 """Test floating point deconstructions and floor methods
 """
 import sys
+from contextlib import nullcontext
 
 import numpy as np
 import pytest
+from packaging.version import Version
 
 from ..casting import (
     FloatingError,
     _check_maxexp,
     _check_nmant,
-    as_int,
     ceil_exact,
     floor_exact,
     floor_log2,
     have_binary128,
-    int_to_float,
     longdouble_precision_improved,
     ok_floats,
     on_powerpc,
+    sctypes,
     type_info,
 )
 from ..testing import suppress_warnings
@@ -26,6 +27,8 @@ IEEE_floats = [np.float16, np.float32, np.float64]
 
 LD_INFO = type_info(np.longdouble)
 
+FP_OVERFLOW_WARN = Version(np.__version__) < Version('2.0.0.dev0')
+
 
 def dtt2dict(dtt):
     """Create info dictionary from numpy type"""
@@ -43,7 +46,7 @@ def dtt2dict(dtt):
 
 def test_type_info():
     # Test routine to get min, max, nmant, nexp
-    for dtt in np.sctypes['int'] + np.sctypes['uint']:
+    for dtt in sctypes['int'] + sctypes['uint']:
         info = np.iinfo(dtt)
         infod = type_info(dtt)
         assert infod == dict(
@@ -123,99 +126,31 @@ def test_check_nmant_nexp():
             assert _check_maxexp(t, ti['maxexp'])
 
 
-def test_as_int():
-    # Integer representation of number
-    assert as_int(2.0) == 2
-    assert as_int(-2.0) == -2
-    with pytest.raises(FloatingError):
-        as_int(2.1)
-    with pytest.raises(FloatingError):
-        as_int(-2.1)
-    assert as_int(2.1, False) == 2
-    assert as_int(-2.1, False) == -2
-    v = np.longdouble(2**64)
-    assert as_int(v) == 2**64
-    # Have all long doubles got 63+1 binary bits of precision?  Windows 32-bit
-    # longdouble appears to have 52 bit precision, but we avoid that by checking
-    # for known precisions that are less than that required
-    try:
-        nmant = type_info(np.longdouble)['nmant']
-    except FloatingError:
-        nmant = 63  # Unknown precision, let's hope it's at least 63
-    v = np.longdouble(2) ** (nmant + 1) - 1
-    assert as_int(v) == 2 ** (nmant + 1) - 1
-    # Check for predictable overflow
-    nexp64 = floor_log2(type_info(np.float64)['max'])
-    with np.errstate(over='ignore'):
-        val = np.longdouble(2**nexp64) * 2  # outside float64 range
-    with pytest.raises(OverflowError):
-        as_int(val)
-    with pytest.raises(OverflowError):
-        as_int(-val)
-
-
-def test_int_to_float():
-    # Convert python integer to floating point
-    # Standard float types just return cast value
-    for ie3 in IEEE_floats:
-        nmant = type_info(ie3)['nmant']
-        for p in range(nmant + 3):
-            i = 2**p + 1
-            assert int_to_float(i, ie3) == ie3(i)
-            assert int_to_float(-i, ie3) == ie3(-i)
-        # IEEEs in this case are binary formats only
-        nexp = floor_log2(type_info(ie3)['max'])
-        # Values too large for the format
-        smn, smx = -(2 ** (nexp + 1)), 2 ** (nexp + 1)
-        if ie3 is np.float64:
-            with pytest.raises(OverflowError):
-                int_to_float(smn, ie3)
-            with pytest.raises(OverflowError):
-                int_to_float(smx, ie3)
-        else:
-            assert int_to_float(smn, ie3) == ie3(smn)
-            assert int_to_float(smx, ie3) == ie3(smx)
-    # Longdoubles do better than int, we hope
-    LD = np.longdouble
-    # up to integer precision of float64 nmant, we get the same result as for
-    # casting directly
+def test_int_longdouble_np_regression():
+    # Test longdouble conversion from int works as expected
+    # Previous versions of numpy would fail, and we used a custom int_to_float()
+    # function. This test remains to ensure we don't need to bring it back.
     nmant = type_info(np.float64)['nmant']
-    for p in range(nmant + 2):  # implicit
-        i = 2**p - 1
-        assert int_to_float(i, LD) == LD(i)
-        assert int_to_float(-i, LD) == LD(-i)
-    # Above max of float64, we're hosed
-    nexp64 = floor_log2(type_info(np.float64)['max'])
-    smn64, smx64 = -(2 ** (nexp64 + 1)), 2 ** (nexp64 + 1)
-    # The algorithm here implemented goes through float64, so supermax and
-    # supermin will cause overflow errors
-    with pytest.raises(OverflowError):
-        int_to_float(smn64, LD)
-    with pytest.raises(OverflowError):
-        int_to_float(smx64, LD)
-    try:
-        nmant = type_info(np.longdouble)['nmant']
-    except FloatingError:  # don't know where to test
-        return
     # test we recover precision just above nmant
     i = 2 ** (nmant + 1) - 1
-    assert as_int(int_to_float(i, LD)) == i
-    assert as_int(int_to_float(-i, LD)) == -i
+    assert int(np.longdouble(i)) == i
+    assert int(np.longdouble(-i)) == -i
     # If longdouble can cope with 2**64, test
     if nmant >= 63:
         # Check conversion to int; the line below causes an error subtracting
         # ints / uint64 values, at least for Python 3.3 and numpy dev 1.8
         big_int = np.uint64(2**64 - 1)
-        assert as_int(int_to_float(big_int, LD)) == big_int
+        assert int(np.longdouble(big_int)) == big_int
 
 
-def test_as_int_np_fix():
-    # Test as_int works for integers.  We need as_int for integers because of a
+def test_int_np_regression():
+    # Test int works as expected for integers.
+    # We previously used a custom as_int() for integers because of a
     # numpy 1.4.1 bug such that int(np.uint32(2**32-1) == -1
-    for t in np.sctypes['int'] + np.sctypes['uint']:
+    for t in sctypes['int'] + sctypes['uint']:
         info = np.iinfo(t)
         mn, mx = np.array([info.min, info.max], dtype=t)
-        assert (mn, mx) == (as_int(mn), as_int(mx))
+        assert (mn, mx) == (int(mn), int(mx))
 
 
 def test_floor_exact_16():
@@ -237,7 +172,9 @@ def test_floor_exact_64():
         assert floor_exact(test_val, np.float64) == 2 ** (e + 1) - int(gap)
 
 
-def test_floor_exact():
+def test_floor_exact(max_digits):
+    max_digits(4950)  # max longdouble is ~10**4932
+
     to_test = IEEE_floats + [float]
     try:
         type_info(np.longdouble)['nmant']
@@ -248,16 +185,16 @@ def test_floor_exact():
         to_test.append(np.longdouble)
     # When numbers go above int64 - I believe, numpy comparisons break down,
     # so we have to cast to int before comparison
-    int_flex = lambda x, t: as_int(floor_exact(x, t))
-    int_ceex = lambda x, t: as_int(ceil_exact(x, t))
+    int_flex = lambda x, t: int(floor_exact(x, t))
+    int_ceex = lambda x, t: int(ceil_exact(x, t))
     for t in to_test:
         # A number bigger than the range returns the max
         info = type_info(t)
-        assert floor_exact(2**5000, t) == np.inf
-        assert ceil_exact(2**5000, t) == np.inf
+        assert floor_exact(10**4933, t) == np.inf
+        assert ceil_exact(10**4933, t) == np.inf
         # A number more negative returns -inf
-        assert floor_exact(-(2**5000), t) == -np.inf
-        assert ceil_exact(-(2**5000), t) == -np.inf
+        assert floor_exact(-(10**4933), t) == -np.inf
+        assert ceil_exact(-(10**4933), t) == -np.inf
         # Check around end of integer precision
         nmant = info['nmant']
         for i in range(nmant + 1):
@@ -286,7 +223,7 @@ def test_floor_exact():
         for i in range(5):
             iv = 2 ** (nmant + 1 + i)
             gap = 2 ** (i + 1)
-            assert as_int(t(iv) + t(gap)) == iv + gap
+            assert int(t(iv) + t(gap)) == iv + gap
             for j in range(1, gap):
                 assert int_flex(iv + j, t) == iv
                 assert int_flex(iv + gap + j, t) == iv + gap
