@@ -40,7 +40,7 @@ from .. import spm2analyze as spm2
 from .. import spm99analyze as spm99
 from ..optpkg import optional_package
 from ..spatialimages import SpatialImage
-from ..testing import expires
+from ..testing import deprecated_to, expires
 from ..tmpdirs import InTemporaryDirectory
 from ..volumeutils import native_code, swapped_code
 
@@ -285,7 +285,7 @@ def test_filename_save():
 @expires('5.0.0')
 def test_guessed_image_type():
     # Test whether we can guess the image type from example files
-    with pytest.deprecated_call():
+    with deprecated_to('5.0.0'):
         assert nils.guessed_image_type(pjoin(DATA_PATH, 'example4d.nii.gz')) == Nifti1Image
         assert nils.guessed_image_type(pjoin(DATA_PATH, 'nifti1.hdr')) == Nifti1Pair
         assert nils.guessed_image_type(pjoin(DATA_PATH, 'example_nifti2.nii.gz')) == Nifti2Image
