@@ -79,7 +79,7 @@ class TestNifti1PairHeader(tana.TestAnalyzeHeader, tspm.HeaderScalingMixin):
         (np.int8, np.uint16, np.uint32, np.int64, np.uint64, np.complex128)
     )
     if have_binary128():
-        supported_np_types = supported_np_types.union((np.longdouble, np.longcomplex))
+        supported_np_types = supported_np_types.union((np.longdouble, np.clongdouble))
     tana.add_duplicate_types(supported_np_types)
 
     def test_empty(self):
@@ -251,7 +251,7 @@ class TestNifti1PairHeader(tana.TestAnalyzeHeader, tspm.HeaderScalingMixin):
         fhdr, message, raiser = self.log_chk(hdr, 45)
         assert fhdr['magic'] == b'ooh'
         assert (
-            message == 'magic string "ooh" is not valid; '
+            message == "magic string 'ooh' is not valid; "
             'leaving as is, but future errors are likely'
         )
         # For pairs, any offset is OK, but should be divisible by 16
@@ -1169,7 +1169,7 @@ class TestNifti1Pair(tana.TestAnalyzeImage, tspm.ImageScalingMixin):
             assert img.get_data_dtype() == alias
             img_rt = bytesio_round_trip(img)
             assert img_rt.get_data_dtype() == effective_dt
-            # Seralizing does not finalize the source image
+            # Serializing does not finalize the source image
             assert img.get_data_dtype() == alias
 
     def test_static_dtype_aliases(self):
