@@ -228,7 +228,7 @@ def test_nib_nifti_dx():
     expected = f"""Picky header check output for "{dirty_hdr}"
 
 pixdim[0] (qfac) should be 1 (default) or -1
-magic string "" is not valid
+magic string '' is not valid
 sform_code 11776 not valid"""
     # Split strings to remove line endings
     assert stdout == expected
@@ -418,7 +418,7 @@ def test_parrec2nii_with_data():
         assert_almost_equal(np.loadtxt('DTI.bvals'), np.sort(DTI_PAR_BVALS))
         img = load('DTI.nii')
         data_sorted = img.get_fdata()
-        assert_almost_equal(data[..., np.argsort(DTI_PAR_BVALS)], data_sorted)
+        assert_almost_equal(data[..., np.argsort(DTI_PAR_BVALS, kind='stable')], data_sorted)
         del img
 
         # Writes .ordering.csv if requested
