@@ -9,7 +9,6 @@
 """Testing spatialimages
 """
 
-import warnings
 from io import BytesIO
 
 import numpy as np
@@ -19,13 +18,7 @@ from numpy.testing import assert_array_almost_equal
 from .. import load as top_load
 from ..imageclasses import spatial_axes_first
 from ..spatialimages import HeaderDataError, SpatialHeader, SpatialImage
-from ..testing import (
-    bytesio_round_trip,
-    clear_and_catch_warnings,
-    expires,
-    memmap_after_ufunc,
-    suppress_warnings,
-)
+from ..testing import bytesio_round_trip, deprecated_to, expires, memmap_after_ufunc
 from ..tmpdirs import InTemporaryDirectory
 
 
@@ -375,7 +368,7 @@ class TestSpatialImage:
         in_data = in_data_template.copy()
         img = img_klass(in_data, None)
         assert in_data is img.dataobj
-        with pytest.deprecated_call():
+        with deprecated_to('5.0.0'):
             out_data = img.get_data()
         assert in_data is out_data
         # and that uncache has no effect
@@ -388,18 +381,18 @@ class TestSpatialImage:
         rt_img = bytesio_round_trip(img)
         assert in_data is not rt_img.dataobj
         assert (rt_img.dataobj == in_data).all()
-        with pytest.deprecated_call():
+        with deprecated_to('5.0.0'):
             out_data = rt_img.get_data()
         assert (out_data == in_data).all()
         assert rt_img.dataobj is not out_data
         # cache
-        with pytest.deprecated_call():
+        with deprecated_to('5.0.0'):
             assert rt_img.get_data() is out_data
         out_data[:] = 42
         rt_img.uncache()
-        with pytest.deprecated_call():
+        with deprecated_to('5.0.0'):
             assert rt_img.get_data() is not out_data
-        with pytest.deprecated_call():
+        with deprecated_to('5.0.0'):
             assert (rt_img.get_data() == in_data).all()
 
     def test_slicer(self):
@@ -540,15 +533,15 @@ class TestSpatialImage:
                     sliceobj = tuple(np.random.choice(slice_elems, n_elems))
                     try:
                         sliced_img = img.slicer[sliceobj]
-                    except (IndexError, ValueError):
-                        # Only checking valid slices
-                        pass
-                    else:
-                        sliced_data = in_data[sliceobj]
-                        assert (sliced_data == sliced_img.get_fdata()).all()
-                        assert (sliced_data == sliced_img.dataobj).all()
-                        assert (sliced_data == img.dataobj[sliceobj]).all()
-                        assert (sliced_data == img.get_fdata()[sliceobj]).all()
+                    except (IndexError, ValueError, HeaderDataError):
+                        # Skip invalid slices or images that can't be created
+                        continue
+
+                    sliced_data = in_data[sliceobj]
+                    assert np.array_equal(sliced_data, sliced_img.get_fdata())
+                    assert np.array_equal(sliced_data, sliced_img.dataobj)
+                    assert np.array_equal(sliced_data, img.dataobj[sliceobj])
+                    assert np.array_equal(sliced_data, img.get_fdata()[sliceobj])
 
 
 class MmapImageMixin:
